ChipGenerator

package module
v0.0.0-...-f409c44 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 9, 2023 License: GPL-3.0 Imports: 5 Imported by: 0

README

ChipGenerator

A Go program to create and import poker chips of ridiculous and insane values.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Chip

type Chip struct {
	// contains filtered or unexported fields
}

type Config

type Config struct {
	IO
	Chip
}

type CustomChip

type CustomChip struct {
	Magnitude   *big.Int
	StartDigits float32
	Colors      []string
}

== structs ==

func (CustomChip) GenerateIllion

func (c CustomChip) GenerateIllion() string

GenerateIllion takes a number and returns a string with the number in illion form, where the number is the illion in the sequence of illions. takes in a big.Int and returns a string. examples: 1 -> "million", 10 -> "decillion", 24 -> "quattorvigintillion" etc.

type IO

type IO struct {
	// contains filtered or unexported fields
}

Directories

Path Synopsis

Jump to