Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CustomChip ¶
== structs ==
func (CustomChip) GenerateIllion ¶
func (c CustomChip) GenerateIllion() string
GenerateIllion takes a number and returns a string with the number in illion form, where the number is the illion in the sequence of illions. takes in a big.Int and returns a string. examples: 1 -> "million", 10 -> "decillion", 24 -> "quattorvigintillion" etc.
Click to show internal directories.
Click to hide internal directories.